[% extends "base.html" %]
[% set name = 'Inspector' %]

[% block content %]
<div id="app">
    <inspector></inspector>
</div>
[% endblock %]

[% block modal %]
    [% include 'index_v1/new_record_modal.html' %] 
    [% include 'index_v1/request_detail_modal.html'%]
[% endblock %] 

[% block scripts %]

<script>var require = {paths: {'vs': '/static/plugins/monaco-editor/min/vs'}};</script>
<script src="/static/plugins/monaco-editor/min/vs/loader.js"></script>
<script src="/static/plugins/monaco-editor/min/vs/editor/editor.main.nls.js"></script>
<script src="/static/plugins/monaco-editor/min/vs/editor/editor.main.js"></script>

<script src="/static/js/inspector.js"></script> 
[% endblock %]
